==> apache-servicecomb-java-chassis-distribution-1.2.0-src.zip: apache-servicecomb-java-chassis-distribution-1.2.0-src/integration-tests/it-common/src/main/java/org/apache/servicecomb/it/schema/User.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import org.apache.servicecomb.foundation.common.utils.JsonUtils;

import com.fasterxml.jackson.core.JsonProcessingException;

public class User {
  private String name = "nameA";

  private int age = 100;

  private int index;

  private String[] names;

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String[] getNames() {
    return names;
  }

  public void setNames(String[] names) {
    this.names = names;
  }

  public int getAge() {
    return age;
  }

  public void setAge(int age) {
    this.age = age;
  }

  public int getIndex() {
    return index;
  }

  public void setIndex(int index) {
    this.index = index;
  }

  @Override
  public String toString() {
    return "User [name=" + name + ", age=" + age + ", index=" + index + "]";
  }

  public String jsonString() {
    try {
      return JsonUtils.writeValueAsString(this);
    } catch (JsonProcessingException e) {
      throw new IllegalStateException(e);
    }
  }
}

==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/integration-tests/it-common/src/main/java/org/apache/servicecomb/it/schema/User.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import java.util.Arrays;
import java.util.Objects;

import org.apache.servicecomb.foundation.common.utils.JsonUtils;

import com.fasterxml.jackson.core.JsonProcessingException;

public class User {
  private String name = "nameA";

  private int age = 100;

  private int index;

  private String[] names;

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String[] getNames() {
    return names;
  }

  public void setNames(String[] names) {
    this.names = names;
  }

  public int getAge() {
    return age;
  }

  public void setAge(int age) {
    this.age = age;
  }

  public int getIndex() {
    return index;
  }

  public void setIndex(int index) {
    this.index = index;
  }

  @Override
  public String toString() {
    return "User [name=" + name + ", age=" + age + ", index=" + index + "]";
  }

  public String jsonString() {
    try {
      return JsonUtils.writeValueAsString(this);
    } catch (JsonProcessingException e) {
      throw new IllegalStateException(e);
    }
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    User user = (User) o;
    return age == user.age &&
        index == user.index &&
        name == null ? user.name == null : name.equals(user.name) &&
        names == null ? user.names == null : Arrays.equals(names, user.names);
  }

  @Override
  public int hashCode() {
    int result = Objects.hash(name, age, index);
    result = 31 * result + Arrays.hashCode(names);
    return result;
  }
}
